@@ -13,26 +13,26 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers_async
-from google.api_core import operations_v1
+from google.api_core import gapic_v1, grpc_helpers_async, operations_v1
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
-from google.cloud.gke_backup_v1.types import backup
-from google.cloud.gke_backup_v1.types import backup_plan
-from google.cloud.gke_backup_v1.types import gkebackup
-from google.cloud.gke_backup_v1.types import restore
-from google.cloud.gke_backup_v1.types import restore_plan
-from google.cloud.gke_backup_v1.types import volume
-from google.longrunning import operations_pb2  # type: ignore
-from .base import BackupForGKETransport, DEFAULT_CLIENT_INFO
+from google.cloud.gke_backup_v1.types import (
+    backup,
+    backup_plan,
+    gkebackup,
+    restore,
+    restore_plan,
+    volume,
+)
+
+from .base import DEFAULT_CLIENT_INFO, BackupForGKETransport
 from .grpc import BackupForGKEGrpcTransport
 
 
@@ -58,7 +58,7 @@ class BackupForGKEGrpcAsyncIOTransport(BackupForGKETransport):
     def create_channel(
         cls,
         host: str = "gkebackup.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -101,15 +101,15 @@ class BackupForGKEGrpcAsyncIOTransport(BackupForGKETransport):
         self,
         *,
         host: str = "gkebackup.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
-        channel: aio.Channel = None,
-        api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
-        quota_project_id=None,
+        channel: Optional[aio.Channel] = None,
+        api_mtls_endpoint: Optional[str] = None,
+        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
         api_audience: Optional[str] = None,
